import { __awaiter, __decorate } from "tslib";
import { Events } from '@ag-grid-community/core';
import { attr, customElement, FASTElement, observable } from '@microsoft/fast-element';
import { buttonCellRenderer } from '../utils';
import { listStyles } from './list.styles';
import { listTemplate } from './list.template';
let List = class List extends FASTElement {
    constructor() {
        super(...arguments);
        this.resourceName = '';
        this.title = '';
        this.hideEdit = false;
        this.hideDelete = false;
        this.actionButtonsConfig = [];
        this.edit = (e) => {
            this.$emit('edit-entity', e);
        };
    }
    connectedCallback() {
        super.connectedCallback();
        this.grid.addEventListener('onGridReady', () => {
            this.grid.gridApi.addEventListener(Events.EVENT_FIRST_DATA_RENDERED, () => {
                if (this.sizeColumnsToFit) {
                    this.grid.gridApi.sizeColumnsToFit();
                }
            });
            this.grid.gridApi.addEventListener('rowClicked', (e) => this.select(e));
            this.actionButtonsConfig = [];
            if (this.deleteEvent && !this.hideDelete) {
                this.actionButtonsConfig.push(buttonCellRenderer('Delete', (e) => this.delete(e)));
            }
            if (this.updateEvent && !this.hideEdit) {
                this.actionButtonsConfig.push(buttonCellRenderer('Edit', this.edit));
            }
            if (this.enableFilterBar) {
                this.addEventListener('filter-changed', this.handleFilterChanged);
                this.addEventListener('filter-cleared', this.handleFilterCleared);
            }
        });
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        if (this.enableFilterBar) {
            this.removeEventListener('filter-changed', this.handleFilterChanged);
            this.removeEventListener('filter-cleared', this.handleFilterCleared);
        }
    }
    handleFilterChanged(e) {
        var _a, _b;
        const fieldName = (_a = e === null || e === void 0 ? void 0 : e.detail) === null || _a === void 0 ? void 0 : _a.fieldName;
        const filter = (_b = e === null || e === void 0 ? void 0 : e.detail) === null || _b === void 0 ? void 0 : _b.filter;
        fieldName && filter && this.datasource.setFilter(fieldName, filter);
    }
    handleFilterCleared(e) {
        var _a;
        const fieldName = (_a = e === null || e === void 0 ? void 0 : e.detail) === null || _a === void 0 ? void 0 : _a.fieldName;
        this.datasource.removeFilter(fieldName);
    }
    select(e) {
        this.$emit('rowSelected', e);
    }
    delete(e) {
        return __awaiter(this, void 0, void 0, function* () {
            this.$emit('delete-entity', e);
        });
    }
};
__decorate([
    attr
], List.prototype, "resourceName", void 0);
__decorate([
    attr
], List.prototype, "title", void 0);
__decorate([
    attr({ attribute: 'persist-column-state-key' })
], List.prototype, "persistColumnStateKey", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'size-columns-to-fit' })
], List.prototype, "sizeColumnsToFit", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'enable-filter-bar' })
], List.prototype, "enableFilterBar", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'enable-cell-flashing' })
], List.prototype, "enableCellFlashing", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'hide-edit' })
], List.prototype, "hideEdit", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'hide-delete' })
], List.prototype, "hideDelete", void 0);
__decorate([
    observable
], List.prototype, "gridOptions", void 0);
__decorate([
    observable
], List.prototype, "columns", void 0);
__decorate([
    observable
], List.prototype, "datasourceConfig", void 0);
__decorate([
    observable
], List.prototype, "actionButtonsConfig", void 0);
__decorate([
    observable
], List.prototype, "deleteEvent", void 0);
__decorate([
    observable
], List.prototype, "updateEvent", void 0);
List = __decorate([
    customElement({
        name: 'entity-list',
        template: listTemplate,
        styles: listStyles,
    })
], List);
export { List };
